@@ -10,7 +10,7 @@ classifiers = [
  
 setup(
   name='asre_compute',
-  version='0.0.3',
+  version='0.0.10',
   description='From a pandas dataframe, this program computes through A-learning the ARE or cognitive biais ASRE along their 95% confidence intervals.',
   long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
   url='',  
@@ -19,6 +19,6 @@ setup(
   license='MIT', 
   classifiers=classifiers,
   keywords='', 
-  packages=find_packages(),
+  packages=['asre_compute'],
   install_requires=[''] 
 )
\ No newline at end of file
